/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02155
 |         WASHINGTON, DC, METROPOLITAN AREA DRUG STUDY(DC*MADS),
 |              1991: HOUSEHOLD AND NONHOUSEHOLD POPULATIONS
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02155-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE catage    -9='(-9) Missing' 1='(1) 12-17' 2='(2) 18-25' 3='(3) 26-34' 4='(4) 35 or over' ;
  VALUE educat1c  -9='(-9) Missing' 1='(1) Less than H.S.' 2='(2) H.S. graduate'
                  3='(3) Some college/college graduate' 4='(4) 12 to 17 years old' ;
  VALUE empstatf  -9='(-9) Missing' 1='(1) Full time' 2='(2) Part time' 3='(3) Unemployed'
                  4='(4) Other' 5='(5) 12 to 17 years old' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE marstat   -9='(-9) Missing' 1='(1) Single' 2='(2) Married' 3='(3) Widowed/div/sep' ;
  VALUE race      -9='(-9) Missing' 1='(1) White' 2='(2) Black' 3='(3) Hispanic' 4='(4) Other' ;
  VALUE alcmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE alcyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE cigmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE cigyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE cocmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE cocyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE crkmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE crkyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE halmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE halyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE hermon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE heryr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE hvydrk2f  -9='(-9) Missing' 0='(0) No heavy drinking-past 30 days'
                  1='(1) Heavy drinking-past 30 days' ;
  VALUE iemmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE iemyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE inhmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE inhyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE mrjmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE mrjyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE ndlshr    -9='(-9) Missing' 0='(0) Has never shared needle'
                  1='(1) Has shared needle in lifetime' ;
  VALUE nedflagf  -9='(-9) Missing' 0='(0) Has never used in lifetime'
                  1='(1) Has used in lifetime' ;
  VALUE nedmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE nedyr3ff  -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE psymon2f  -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE psyyr2ff  -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE stamon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE stayr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE stmmon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE stmyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE summon    -9='(-9) Missing' 0='(0) Did not use w/in past month'
                  1='(1) Used w/in past month' ;
  VALUE sumyr     -9='(-9) Missing' 0='(0) Did not use w/in past year'
                  1='(1) Used w/in past year' ;
  VALUE drugovlp  -9='(-9) Missing' 1='(1) Crack user only' 2='(2) Heroin user only'
                  3='(3) Needle user only' 4='(4) Crack/heroin user only'
                  5='(5) Crack/needle user only' 6='(6) Heroin/needle user only'
                  7='(7) Crk/her/needle user' 8='(8) Crk/her/needle nonuser' ;
  VALUE overlap   1='(1) NHSDA only' 2='(2) Institutional only' 3='(3) Homeless only'
                  4='(4) Not literally homeless' 5='(5) Institutional group homes'
                  6='(6) Homeless, Shelters' 7='(7) Overlap-2 surveys' ;
  VALUE survey    1='(1) 1991 DC Household' 2='(2) Homeless' 3='(3) Institutionalized' ;
  VALUE survey1f  0='(0) Other' 1='(1) DC Household' ;
  VALUE survey2f  0='(0) Other' 1='(1) Homeless' ;
  VALUE survey3f  0='(0) Other' 1='(1) Institutionalized' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=121;
INPUT
        CASEID 1-4              OBSNUM 5-8              CATAGE 9-10
        EDUCAT1C 11-12          EMPSTAT2 13-14          IRSEX 15
        MARSTAT 16-17           RACE 18-19              ALCMON 20-21
        ALCYR 22-23             CIGMON 24-25            CIGYR 26-27
        COCMON 28-29            COCYR 30-31             CRKMON 32-33
        CRKYR 34-35             HALMON 36-37            HALYR 38-39
        HERMON 40-41            HERYR 42-43             HVYDRK2 44-45
        IEMMON 46-47            IEMYR 48-49             INHMON 50-51
        INHYR 52-53             MRJMON 54-55            MRJYR 56-57
        NDLSHR 58-59            NEDFLAG3 60-61          NEDMON 62-63
        NEDYR3 64-65            PSYMON2 66-67           PSYYR2 68-69
        STAMON 70-71            STAYR 72-73             STMMON 74-75
        STMYR 76-77             SUMMON 78-79            SUMYR 80-81
        DRUGOVLP 82-83          OVERLAP 84              SURVEY 85
        SURVEY1 86              SURVEY2 87              SURVEY3 88
        MULTWT 89-98 .4         STRATUM 99-105          WEIGHT 106-115 .4
        WPSU 116-121            ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'Case Identification Number'
   OBSNUM  = 'Observation Number'
   CATAGE  = 'Age Category'
   EDUCAT1C= 'Categorized/Collapsed Education'
   EMPSTAT2= 'Employment Status Recode'
   IRSEX   = 'Sex-Imputation Revised'
   MARSTAT = 'Marital Status-Categorized'
   RACE    = 'Race/Hispanic-Origin Recode'
   ALCMON  = 'Alcohol-Past Month Use'
   ALCYR   = 'Alcohol-Past Year Use'
   CIGMON  = 'Cigarettes-Past Month Use'
   CIGYR   = 'Cigarettes-Past Year Use'
   COCMON  = 'Cocaine-Past Month Use (Includes Crack)'
   COCYR   = 'Cocaine-Past Year Use (Includes Crack)'
   CRKMON  = 'Crack-Past Month Use'
   CRKYR   = 'Crack-Past Year Use'
   HALMON  = 'Hallucinogens-Past Month Use'
   HALYR   = 'Hallucinogens-Past Year Use'
   HERMON  = 'Heroin-Past Month Use'
   HERYR   = 'Heroin-Past Year Use'
   HVYDRK2 = 'Drank Alcohol Heavily-Past 30 Days'
   IEMMON  = 'Illicit Drug Use(Except MJ)-Past Month'
   IEMYR   = 'Illicit Drug Use(Except MJ)-Past Year'
   INHMON  = 'Inhalants-Past Month Use'
   INHYR   = 'Inhalants-Past Year Use'
   MRJMON  = 'Marijuana-Past Month Use (Incl Hash)'
   MRJYR   = 'Marijuana-Past Year Use (Incl Hash)'
   NDLSHR  = 'Needle Sharing Indicator'
   NEDFLAG3= 'Needle Use (Any Drug)-Lifetime Use'
   NEDMON  = 'Needle Use (Any Drug)-Past Month Use'
   NEDYR3  = 'Needle Use (Any Drug)-Past Year Use'
   PSYMON2 = 'Any Psychotherapeutics-Past Mo(Non-Med Use)'
   PSYYR2  = 'Any Psychotherapeutics-Past Yr(Non-Med Use)'
   STAMON  = 'Sed/Tranq/Analgesics-Past Month Use'
   STAYR   = 'Sed/Tranq/Analgesics-Past Year Use'
   STMMON  = 'Stimulants-Past Month Use'
   STMYR   = 'Stimulants-Past Year Use'
   SUMMON  = 'Any Illicit Drug-Past Month Use'
   SUMYR   = 'Any Illicit Drug-Past Year Use'
   DRUGOVLP= 'Overlap Past Yr Crack,Heroin,&Needle Use'
   OVERLAP = 'Overlap of Surveys'
   SURVEY  = 'Survey Type'
   SURVEY1 = 'DC Household'
   SURVEY2 = 'Homeless'
   SURVEY3 = 'Institutionalized'
   MULTWT  = 'Multiplicity Adj Wt for Combined File'
   STRATUM = 'Stratum for SUDAAN'
   WEIGHT  = 'Original Analysis Weights Combined'
   WPSU    = 'PSU for SUDAAN'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (OBSNUM = -9) THEN OBSNUM = .;
   IF (CATAGE = -9) THEN CATAGE = .;
   IF (EDUCAT1C = -9) THEN EDUCAT1C = .;
   IF (EMPSTAT2 = -9) THEN EMPSTAT2 = .;
   IF (IRSEX = -9) THEN IRSEX = .;
   IF (MARSTAT = -9) THEN MARSTAT = .;
   IF (RACE = -9) THEN RACE = .;
   IF (ALCMON = -9) THEN ALCMON = .;
   IF (ALCYR = -9) THEN ALCYR = .;
   IF (CIGMON = -9) THEN CIGMON = .;
   IF (CIGYR = -9) THEN CIGYR = .;
   IF (COCMON = -9) THEN COCMON = .;
   IF (COCYR = -9) THEN COCYR = .;
   IF (CRKMON = -9) THEN CRKMON = .;
   IF (CRKYR = -9) THEN CRKYR = .;
   IF (HALMON = -9) THEN HALMON = .;
   IF (HALYR = -9) THEN HALYR = .;
   IF (HERMON = -9) THEN HERMON = .;
   IF (HERYR = -9) THEN HERYR = .;
   IF (HVYDRK2 = -9) THEN HVYDRK2 = .;
   IF (IEMMON = -9) THEN IEMMON = .;
   IF (IEMYR = -9) THEN IEMYR = .;
   IF (INHMON = -9) THEN INHMON = .;
   IF (INHYR = -9) THEN INHYR = .;
   IF (MRJMON = -9) THEN MRJMON = .;
   IF (MRJYR = -9) THEN MRJYR = .;
   IF (NDLSHR = -9) THEN NDLSHR = .;
   IF (NEDFLAG3 = -9) THEN NEDFLAG3 = .;
   IF (NEDMON = -9) THEN NEDMON = .;
   IF (NEDYR3 = -9) THEN NEDYR3 = .;
   IF (PSYMON2 = -9) THEN PSYMON2 = .;
   IF (PSYYR2 = -9) THEN PSYYR2 = .;
   IF (STAMON = -9) THEN STAMON = .;
   IF (STAYR = -9) THEN STAYR = .;
   IF (STMMON = -9) THEN STMMON = .;
   IF (STMYR = -9) THEN STMYR = .;
   IF (SUMMON = -9) THEN SUMMON = .;
   IF (SUMYR = -9) THEN SUMYR = .;
   IF (DRUGOVLP = -9) THEN DRUGOVLP = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CATAGE catage. EDUCAT1C educat1c. EMPSTAT2 empstatf.
         IRSEX irsex. MARSTAT marstat. RACE race.
         ALCMON alcmon. ALCYR alcyr. CIGMON cigmon.
         CIGYR cigyr. COCMON cocmon. COCYR cocyr.
         CRKMON crkmon. CRKYR crkyr. HALMON halmon.
         HALYR halyr. HERMON hermon. HERYR heryr.
         HVYDRK2 hvydrk2f. IEMMON iemmon. IEMYR iemyr.
         INHMON inhmon. INHYR inhyr. MRJMON mrjmon.
         MRJYR mrjyr. NDLSHR ndlshr. NEDFLAG3 nedflagf.
         NEDMON nedmon. NEDYR3 nedyr3ff. PSYMON2 psymon2f.
         PSYYR2 psyyr2ff. STAMON stamon. STAYR stayr.
         STMMON stmmon. STMYR stmyr. SUMMON summon.
         SUMYR sumyr. DRUGOVLP drugovlp. OVERLAP overlap.
         SURVEY survey. SURVEY1 survey1f. SURVEY2 survey2f.
         SURVEY3 survey3f.  ;
*/

RUN ;
